@@ -784,17 +784,18 @@ static int
 basep_widget_focus_in_event (GtkWidget     *widget,
 			     GdkEventFocus *event)
 {
+#if 0
 	BasePWidget *basep = BASEP_WIDGET (widget);
 
-	if (basep->state == BASEP_AUTO_HIDDEN)
-		basep_widget_autoshow (basep);
-
-#if 0
-        /* FIXME: When we have focus and hit ctrl-alt-tab with
+        /* FIXME: #89180 - we should show explicitly hidden
+	 *	  panels here.
+	 * 
+	 *        When we have focus and hit ctrl-alt-tab with
          *        Metacity, it does a grab and we a FocusChange
          *        event because gdk doesn't ignore NotifyGrab
          *        FocusChange events. See #ifdefed out case
-         *        in gdkevents-x11.c.
+         *        in gdkevents-x11.c. This is detailed in #89179,
+	 *        which blocks #89180.
          */
         else if (basep->state == BASEP_HIDDEN_LEFT ||
                  basep->state == BASEP_HIDDEN_RIGHT)
@@ -838,9 +839,7 @@ basep_enter_notify (GtkWidget *widget,
 	    event->detail != GDK_NOTIFY_INFERIOR) {
 
 		g_assert (basep->mode == BASEP_AUTO_HIDE);
-#ifdef BASEP_WIDGET_DEBUG
-		g_print ("detail: %d\n", event->detail);
-#endif
+
 		if (basep->leave_notify_timer_tag != 0) {
 			g_source_remove (basep->leave_notify_timer_tag);
 			basep->leave_notify_timer_tag = 0;
@@ -1379,6 +1378,7 @@ basep_widget_instance_init (BasePWidget *basep)
 	gtk_widget_show(basep->ebox);
 
 	basep->table = gtk_table_new(3,3,FALSE);
+	gtk_widget_set_direction (basep->table, GTK_TEXT_DIR_LTR);
 	gtk_container_add(GTK_CONTAINER(basep->ebox),basep->table);
 	gtk_widget_show(basep->table);
 
@@ -2053,12 +2053,8 @@ basep_widget_queue_autoshow (BasePWidget *basep)
         /* check if there's already a timeout set, and delete it if 
          * there was */
 
-	if (basep->moving) {
-#ifdef BASEP_WIDGET_DEBUG
-		g_print ("basep_widget_queue_autoshow: return 2");
-#endif
+	if (basep->moving)
 		return; 
-	}
 
         if (basep->leave_notify_timer_tag != 0) {
                 g_source_remove (basep->leave_notify_timer_tag);
@@ -2067,19 +2063,11 @@ basep_widget_queue_autoshow (BasePWidget *basep)
 
         if (basep->enter_notify_timer_tag != 0) {
                 g_source_remove (basep->enter_notify_timer_tag);
-#ifdef BASEP_WIDGET_DEBUG
-		g_print ("basep_widget_queue_autoshow: <timeout removed>\n");
-#endif
 	}
 
         if ((basep->mode != BASEP_AUTO_HIDE) ||
-            (basep->state == BASEP_SHOWN)) {
-#ifdef BASEP_WIDGET_DEBUG
-		g_print ("basep_widget_queue_autoshow: return 1\n");
-#endif
+            (basep->state == BASEP_SHOWN))
                 return;
-	}
-
 
 	if (global_config.hide_delay == 0) {
 		/* set up our idle for popup. */
@@ -2435,7 +2423,6 @@ basep_calculate_borders (int screen)
 
 		if (EDGE_IS_WIDGET (basep)) {
 			BasePState state = basep->state;
-			int        size = 0;
 
 			switch (state) {
 			case BASEP_HIDDEN_RIGHT:
